#!/usr/bin/env python3
import pathlib, subprocess, sys, pandas

from Bio import SeqIO
                
HEADER = ["Isolate\tLength\tAligned\tUnaligned\tHeterozygous\tLow coverage\t% Aligned"]

def check_snippy(isolate,aln):
    
    p = pathlib.Path(aln)
    fasta = p.open()
    length = 0
    nocov = 0
    lowcov = 0
    het = 0
    unaln = 0
    for i in SeqIO.parse(fasta,'fasta'): # use BioPython to determine percent alignment
        length = length + len(i.seq)
        nocov = nocov + i.seq.count('-')
        lowcov = lowcov + i.seq.count('N')
        het = het + i.seq.count('n')
    unaln = unaln + nocov + lowcov + het
    aln = length - unaln
    perc_aln = 100*(length - unaln) / length
    # quality = 'PASS' if perc_aln > float(minaln) else 'FAIL'
    return length,aln, nocov, lowcov, het, unaln, perc_aln

def main(inputs, isolate, output):

    length, aln, nocov, lowcov, het, unaln, perc_aln= check_snippy(aln = inputs, isolate = isolate)
    data = [isolate, length, aln, unaln,het,lowcov,round(perc_aln, 2)]
    data = [f"{d}" for d in data]
    data = "\t".join(data)
    HEADER.append(data)
    out = pathlib.Path(output)
    out.write_text("\n".join(HEADER))
    # print(data)
   
# {input} {wildcards.sample} {output} {params.minaln}
inputs = sys.argv[2]
isolate = sys.argv[1]
output = sys.argv[3]


main(inputs = inputs, isolate = isolate, output = output)



import click
import pathlib
import os
from bohra.launcher.TestBohra import run_tests

@click.command()
@click.option('--cpus',
              default=1,
              help="Number of CPUs to use for testing Bohra installation.") 
@click.option('--shovill_ram',
              default=16,
              help="Amount of RAM to allocate to shovill assembler.") 
@click.option('--wdir',
              default=str(pathlib.Path.cwd()),
              help="Working directory for the test run. Default is the current working directory.")
def test(cpus:int=1, shovill_ram:int=16, wdir:str=str(pathlib.Path.cwd())):
    """
    Check that bohra is installed correctly and runs as expected.
    """
    
    run_tests(cpus=cpus, shovill_ram=shovill_ram, wdir=wdir)


#!/usr/bin/env python3

import sys, json, pathlib


available_species = json.load(open(f"{pathlib.Path(__file__).parent.resolve() / 'species.json'}", 'r'))
species_obs = sys.argv[1].strip()

if species_obs.replace(" ", "_") in available_species['abritamr_species'] :
    print(f"-sp {species_obs.replace(' ', '_')}")
elif species_obs.split()[0] in available_species['abritamr_species'] :
    print(f"-sp {species_obs.split()[0]}")
elif species_obs in available_species['abritamr_synonyms'] :
    print(f"-sp {available_species['abritamr_synonyms'][species_obs]}")
else:
    print("")